<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<context>
    <name>QInputMethod</name>
    <message>
        <source>InputMethod is an abstract class</source>
        <translation>InputMethod - це абстрактний клас</translation>
    </message>
</context>
<context>
    <name>QQmlCompiler</name>
    <message>
        <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
        <translation>Неправильне присвоєння властивості: властивість &quot;%1&quot; лише для читання</translation>
    </message>
    <message>
        <source>Invalid property assignment: unknown enumeration</source>
        <translation>Неправильне присвоєння властивості: невідомий перелік</translation>
    </message>
    <message>
        <source>Invalid property assignment: string expected</source>
        <translation>Неправильне присвоєння властивості: очікувався рядок</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or string list expected</source>
        <translation>Неправильне присвоєння властивості: очікувались рядок або список рядків</translation>
    </message>
    <message>
        <source>Invalid property assignment: byte array expected</source>
        <translation>Неправильне присвоєння властивості: очікувався масив байтів</translation>
    </message>
    <message>
        <source>Invalid property assignment: url expected</source>
        <translation>Неправильне присвоєння властивості: очікувався URL</translation>
    </message>
    <message>
        <source>Invalid property assignment: regular expression expected; use /pattern/ syntax</source>
        <translation>Неправильне присвоєння властивості: очікувався регулярний вираз, використовуйте синтаксис /pattern/</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsigned int expected</source>
        <translation>Неправильне присвоєння властивості: очікувалось беззнакове ціле</translation>
    </message>
    <message>
        <source>Invalid property assignment: int expected</source>
        <translation>Неправильне присвоєння властивості: очікувалось ціле</translation>
    </message>
    <message>
        <source>Invalid property assignment: number expected</source>
        <translation>Неправильне присвоєння властивості: очікувалось число</translation>
    </message>
    <message>
        <source>Invalid property assignment: color expected</source>
        <translation>Неправильне присвоєння властивості: очікувався колір</translation>
    </message>
    <message>
        <source>Invalid property assignment: date expected</source>
        <translation>Неправильне присвоєння властивості: очікувалась дата</translation>
    </message>
    <message>
        <source>Invalid property assignment: time expected</source>
        <translation>Неправильне присвоєння властивості: очікувався час</translation>
    </message>
    <message>
        <source>Invalid property assignment: datetime expected</source>
        <translation>Неправильне присвоєння властивості: очікувались дата та час</translation>
    </message>
    <message>
        <source>Invalid property assignment: point expected</source>
        <translation>Неправильне присвоєння властивості: очікувалась точка</translation>
    </message>
    <message>
        <source>Invalid property assignment: size expected</source>
        <translation>Неправильне присвоєння властивості: очікувався розмір</translation>
    </message>
    <message>
        <source>Invalid property assignment: rect expected</source>
        <translation>Неправильне присвоєння властивості: очікувався прямокутник</translation>
    </message>
    <message>
        <source>Invalid property assignment: boolean expected</source>
        <translation>Неправильне присвоєння властивості: очікувалось булеве</translation>
    </message>
    <message>
        <source>Invalid property assignment: 3D vector expected</source>
        <translation>Неправильне присвоєння властивості: очікувався тривимірний вектор</translation>
    </message>
    <message>
        <source>Invalid property assignment: 4D vector expected</source>
        <translation>Неправильне присвоєння властивості: очікувався чотиривимірний вектор</translation>
    </message>
    <message>
        <source>Invalid property assignment: real or array of reals expected</source>
        <translation>Неправильне присвоєння властивості: очікувались дійсне число або масив дійсних чисел</translation>
    </message>
    <message>
        <source>Invalid property assignment: int or array of ints expected</source>
        <translation>Неправильне присвоєння властивості: очікувались ціле число або масив цілих чисел</translation>
    </message>
    <message>
        <source>Invalid property assignment: bool or array of bools expected</source>
        <translation>Неправильне присвоєння властивості: очікувались булеве значення або масив булевих значень</translation>
    </message>
    <message>
        <source>Invalid property assignment: string or array of strings expected</source>
        <translation>Неправильне присвоєння властивості: очікувались рядок або масив рядків</translation>
    </message>
    <message>
        <source>Invalid property assignment: url or array of urls expected</source>
        <translation>Неправильне присвоєння властивості: очікувались url або масив url</translation>
    </message>
    <message>
        <source>Invalid property assignment: unsupported type &quot;%1&quot;</source>
        <translation>Неправильне присвоєння властивості: непідтримуваний тип &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Element is not creatable.</source>
        <translation>Елемент не є створюваним.</translation>
    </message>
    <message>
        <source>Component elements may not contain properties other than id</source>
        <translation>Елементи Component не можуть містити властивостей окрім id</translation>
    </message>
    <message>
        <source>Invalid component id specification</source>
        <translation>Неправильна специфікація ідентифікатора компоненти</translation>
    </message>
    <message>
        <source>id is not unique</source>
        <translation>ідентифікатор не унікальний</translation>
    </message>
    <message>
        <source>Invalid component body specification</source>
        <translation>Неправильна специфікація тіла компоненти</translation>
    </message>
    <message>
        <source>Component objects cannot declare new properties.</source>
        <translation>Об&apos;єкти Component не можуть оголошувати нові властивості.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new signals.</source>
        <translation>Об&apos;єкти Component не можуть оголошувати нові сигнали.</translation>
    </message>
    <message>
        <source>Component objects cannot declare new functions.</source>
        <translation>Об&apos;єкти Component не можуть оголошувати нові функції.</translation>
    </message>
    <message>
        <source>Cannot create empty component specification</source>
        <translation>Неможливо створити порожню специфікацію компоненти</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available in %3 %4.%5.</source>
        <translation>&quot;%1.%2&quot; не доступно в %3 %4.%5.</translation>
    </message>
    <message>
        <source>&quot;%1.%2&quot; is not available due to component versioning.</source>
        <translation>&quot;%1.%2&quot; не доступно через версіювання компонента.</translation>
    </message>
    <message>
        <source>Incorrectly specified signal assignment</source>
        <translation>Неправильно вказане призначення сигналу</translation>
    </message>
    <message>
        <source>Cannot assign a value to a signal (expecting a script to be run)</source>
        <translation>Неможливо призначити значення сигналу (очікується скрипт для виконання)</translation>
    </message>
    <message>
        <source>Empty signal assignment</source>
        <translation>Порожнє призначення сигналу</translation>
    </message>
    <message>
        <source>Empty property assignment</source>
        <translation>Порожнє призначення властивості</translation>
    </message>
    <message>
        <source>Attached properties cannot be used here</source>
        <translation>Прикріплені властивості не можуть бути тут використані</translation>
    </message>
    <message>
        <source>Non-existent attached object</source>
        <translation>Неіснуючий прикріплений об&apos;єкт</translation>
    </message>
    <message>
        <source>Invalid attached object assignment</source>
        <translation>Неправильне призначення прикріпленого об&apos;єкта</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent default property</source>
        <translation>Неможливо призначити до неіснуючої типової властивості</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Неможливо призначити неіснуючій властивості &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid use of namespace</source>
        <translation>Неправильне використання простору імен</translation>
    </message>
    <message>
        <source>Not an attached property name</source>
        <translation>Не є назвою прикріпленої властивості</translation>
    </message>
    <message>
        <source>Invalid use of id property</source>
        <translation>Неправильне використання властивості id</translation>
    </message>
    <message>
        <source>Property has already been assigned a value</source>
        <translation>Властивості вже призначено значення</translation>
    </message>
    <message>
        <source>Objects cannot be assigned to value types</source>
        <translation>Об&apos;єкти не можуть бути присвоєні типам значень</translation>
    </message>
    <message>
        <source>Invalid grouped property access</source>
        <translation>Неправильний доступ до згрупованої властивості</translation>
    </message>
    <message>
        <source>Cannot assign a value directly to a grouped property</source>
        <translation>Неможливо призначити значення безпосередньо до згрупованої властивості</translation>
    </message>
    <message>
        <source>Invalid property use</source>
        <translation>Неправильне використання властивості</translation>
    </message>
    <message>
        <source>Property assignment expected</source>
        <translation>Очікувалось призначення властивості</translation>
    </message>
    <message>
        <source>Single property assignment expected</source>
        <translation>Очікується одиночне призначення властивості</translation>
    </message>
    <message>
        <source>Unexpected object assignment</source>
        <translation>Неочікуване призначення об&apos;єкта</translation>
    </message>
    <message>
        <source>Cannot assign object to list</source>
        <translation>Неможливо призначити об&apos;єкт списку</translation>
    </message>
    <message>
        <source>Can only assign one binding to lists</source>
        <translation>Можна призначити лише один зв&apos;язок до списків</translation>
    </message>
    <message>
        <source>Cannot assign primitives to lists</source>
        <translation>Неможливо призначити примітиви до списків</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a script property</source>
        <translation>Неможливо призначити декілька значень властивості скрипту</translation>
    </message>
    <message>
        <source>Invalid property assignment: script expected</source>
        <translation>Неправильне присвоєння властивості: очікувався скрипт</translation>
    </message>
    <message>
        <source>Cannot assign multiple values to a singular property</source>
        <translation>Неможливо присвоїти декілька значенть до одиничної властивості</translation>
    </message>
    <message>
        <source>Cannot assign object to property</source>
        <translation>Неможливо призначити об&apos;єкт властивості</translation>
    </message>
    <message>
        <source>&quot;%1&quot; cannot operate on &quot;%2&quot;</source>
        <translation>&quot;%1&quot; не може оперувати над &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Duplicate default property</source>
        <translation>Дубльована типова властивість</translation>
    </message>
    <message>
        <source>Duplicate property name</source>
        <translation>Дубльована назва властивості</translation>
    </message>
    <message>
        <source>Property names cannot begin with an upper case letter</source>
        <translation>Назви властивостей не можуть починатись з великої літери</translation>
    </message>
    <message>
        <source>Illegal property name</source>
        <translation>Неприпустима назва властивості</translation>
    </message>
    <message>
        <source>Duplicate signal name</source>
        <translation>Дубльована назва сигналу</translation>
    </message>
    <message>
        <source>Signal names cannot begin with an upper case letter</source>
        <translation>Назви сигналів не можуть починатись з великої літери</translation>
    </message>
    <message>
        <source>Illegal signal name</source>
        <translation>Неприпустима назва сигналу</translation>
    </message>
    <message>
        <source>Duplicate method name</source>
        <translation>Дубльована назва методу</translation>
    </message>
    <message>
        <source>Method names cannot begin with an upper case letter</source>
        <translation>Назви методів не можуть починатись з великої літери</translation>
    </message>
    <message>
        <source>Illegal method name</source>
        <translation>Неприпустима назва методу</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>Значення властивості встановлено декілька разів</translation>
    </message>
    <message>
        <source>Invalid property nesting</source>
        <translation>Неправильне вкладення властивостей</translation>
    </message>
    <message>
        <source>Cannot override FINAL property</source>
        <translation>Неможливо перевизначити властивість FINAL</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: %1</source>
        <translation>Неправильний тип параметра сигналу: %1</translation>
    </message>
    <message>
        <source>Duplicate signal name: invalid override of property change signal or superclass signal</source>
        <translation>Назва сигналу повторюється: неправильне перевизначення сигналу зміни властивості або сигналу суперкласу</translation>
    </message>
    <message>
        <source>Duplicate method name: invalid override of property change signal or superclass signal</source>
        <translation>Назва методу повторюється: неправильне перевизначення сигналу зміни властивості або сигналу суперкласу</translation>
    </message>
    <message>
        <source>Invalid property type</source>
        <translation>Неправильний тип властивості</translation>
    </message>
    <message>
        <source>No property alias location</source>
        <translation>Відсутня позиція псевдоніма властивості</translation>
    </message>
    <message>
        <source>Invalid alias location</source>
        <translation>Неправильна позиція псевдоніму</translation>
    </message>
    <message>
        <source>Invalid alias reference. An alias reference must be specified as &lt;id&gt;, &lt;id&gt;.&lt;property&gt; or &lt;id&gt;.&lt;value property&gt;.&lt;property&gt;</source>
        <translation>Неправильне посилання на псевдонім. Посилання на псевдонім повинно бути вказане як &lt;id&gt;, &lt;id&gt;.&lt;властивість&gt; або &lt;id&gt;.&lt;властивість-значення&gt;.&lt;властивість&gt;</translation>
    </message>
    <message>
        <source>Invalid alias reference. Unable to find id &quot;%1&quot;</source>
        <translation>Неправильне посилання на псевдонім. Неможливо знайти id &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid empty ID</source>
        <translation>Неправильний порожній ID</translation>
    </message>
    <message>
        <source>IDs cannot start with an uppercase letter</source>
        <translation>Ідентифікатори не можуть починатись з великої літери</translation>
    </message>
    <message>
        <source>IDs must start with a letter or underscore</source>
        <translation>Ідентифікатори повинні починатись з літери чи підкреслення</translation>
    </message>
    <message>
        <source>IDs must contain only letters, numbers, and underscores</source>
        <translation>Ідентифікатори повинні містити лише літери, цифри та підкреслення</translation>
    </message>
    <message>
        <source>ID illegally masks global JavaScript property</source>
        <translation>Ідентифікатор неправильно маскує глобальну властивість JavaScript</translation>
    </message>
</context>
<context>
    <name>QQmlComponent</name>
    <message>
        <source>Invalid empty URL</source>
        <translation>Неправильний порожній URL</translation>
    </message>
    <message>
        <source>createObject: value is not an object</source>
        <translation>createObject: значення не є об’єктом</translation>
    </message>
    <message>
        <source>Object destroyed during incubation</source>
        <translation>Об&apos;єкт було знищено під час інкубації</translation>
    </message>
</context>
<context>
    <name>QQmlComponentPrivate</name>
    <message>
        <source>Invalid empty URL</source>
        <translation type="obsolete">Неправильний порожній URL</translation>
    </message>
</context>
<context>
    <name>QQmlConnections</name>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Неможливо призначити неіснуючій властивості &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Connections: nested objects not allowed</source>
        <translation>З’єднання: вкладені об’єкти не дозволяються</translation>
    </message>
    <message>
        <source>Connections: syntax error</source>
        <translation>З’єднання: синтаксична помилка</translation>
    </message>
    <message>
        <source>Connections: script expected</source>
        <translation>З’єднання: очікувався скрипт</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModel</name>
    <message>
        <source>The delegate of a DelegateModel cannot be changed within onUpdated.</source>
        <translation>Неможливо змінити делегат DelegateModel всередині onUpdated.</translation>
    </message>
    <message>
        <source>The maximum number of supported DelegateModelGroups is 8</source>
        <translation>Підтримується максимум 8 DelegateModelGroups</translation>
    </message>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Неможливо змінити групу DelegateModel всередині onChanged</translation>
    </message>
</context>
<context>
    <name>QQmlDelegateModelGroup</name>
    <message>
        <source>Group names must start with a lower case letter</source>
        <translation>Назви груп повинні почиантись з малої літери</translation>
    </message>
    <message>
        <source>get: index out of range</source>
        <translation>get: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>insert: index out of range</source>
        <translation>insert: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>create: index out of range</source>
        <translation>create: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>resolve: from index out of range</source>
        <translation>resolve: індекс from поза межами діапазону</translation>
    </message>
    <message>
        <source>resolve: from index invalid</source>
        <translation>resolve: неправильний індекс from</translation>
    </message>
    <message>
        <source>resolve: to index out of range</source>
        <translation>resolve: індекс to поза межами діапазону</translation>
    </message>
    <message>
        <source>resolve: to index invalid</source>
        <translation>resolve: неправильний індекс to</translation>
    </message>
    <message>
        <source>resolve: from is not an unresolved item</source>
        <translation>resolve: from не є нерозв&apos;язаним елементом</translation>
    </message>
    <message>
        <source>resolve: to is not a model item</source>
        <translation>resolve: to не є елементом моделі</translation>
    </message>
    <message>
        <source>remove: invalid index</source>
        <translation>remove: неправильний індекс</translation>
    </message>
    <message>
        <source>remove: index out of range</source>
        <translation>remove: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>remove: invalid count</source>
        <translation>remove: неправильна кількість</translation>
    </message>
    <message>
        <source>addGroups: index out of range</source>
        <translation>addGroups: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>addGroups: invalid count</source>
        <translation>addGroups: неправильна кількість</translation>
    </message>
    <message>
        <source>removeGroups: index out of range</source>
        <translation>removeGroups: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>removeGroups: invalid count</source>
        <translation>removeGroups: неправильна кількість</translation>
    </message>
    <message>
        <source>setGroups: index out of range</source>
        <translation>setGroups: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>setGroups: invalid count</source>
        <translation>setGroups: неправильна кількість</translation>
    </message>
    <message>
        <source>move: invalid from index</source>
        <translation>move: неправильний індекс from</translation>
    </message>
    <message>
        <source>move: invalid to index</source>
        <translation>move: неправильний індекс</translation>
    </message>
    <message>
        <source>move: invalid count</source>
        <translation>move: неправильна кількість</translation>
    </message>
    <message>
        <source>move: from index out of range</source>
        <translation>move: індекс from поза межами діапазону</translation>
    </message>
    <message>
        <source>move: to index out of range</source>
        <translation>move: індекс to поза межами діапазону</translation>
    </message>
</context>
<context>
    <name>QQmlEngine</name>
    <message>
        <source>Locale cannot be instantiated.  Use Qt.locale()</source>
        <translation>Неможливо створити локаль. Використовуйте Qt.locale()</translation>
    </message>
    <message>
        <source>There are still &quot;%1&quot; items in the process of being created at engine destruction.</source>
        <translation>&quot;%1&quot; елементів все ще створюється, в той час як рушій знищується.</translation>
    </message>
    <message>
        <source>executeSql called outside transaction()</source>
        <translation>executeSql було викликано поза transaction()</translation>
    </message>
    <message>
        <source>Read-only Transaction</source>
        <translation>Транзакція лише для читання</translation>
    </message>
    <message>
        <source>Version mismatch: expected %1, found %2</source>
        <translation>Розбіжність версій: очікувалась %1, знайдена %2</translation>
    </message>
    <message>
        <source>SQL transaction failed</source>
        <translation>Збій транзакції SQL</translation>
    </message>
    <message>
        <source>transaction: missing callback</source>
        <translation>транзакція: відсутній зворотній виклик</translation>
    </message>
    <message>
        <source>SQL: can&apos;t create database, offline storage is disabled.</source>
        <translation>SQL: неможливо створити базу даних, автономне сховище вимкнено.</translation>
    </message>
    <message>
        <source>SQL: database version mismatch</source>
        <translation>SQL: розбіжність версій бази даних</translation>
    </message>
</context>
<context>
    <name>QQmlImportDatabase</name>
    <message>
        <source>&quot;%1&quot; is ambiguous. Found in %2 and in %3</source>
        <translation>&quot;%1&quot; є неоднозначним. Знайдено в %2 та в %3</translation>
    </message>
    <message>
        <source>- %1 is not a namespace</source>
        <translation>- %1 не є простором імен</translation>
    </message>
    <message>
        <source>- nested namespaces not allowed</source>
        <translation>- вкладені простори імен не дозволяються</translation>
    </message>
    <message>
        <source>local directory</source>
        <translation>локальна тека</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 and in %2</source>
        <translation>є неоднозначним. Знайдено в %1 та в %2</translation>
    </message>
    <message>
        <source>is ambiguous. Found in %1 in version %2.%3 and %4.%5</source>
        <translation>є неоднозначним. Знайдено в %1 версії %2.%3 та %4.%5</translation>
    </message>
    <message>
        <source>is instantiated recursively</source>
        <translation>інстанціюється рекурсивно</translation>
    </message>
    <message>
        <source>is not a type</source>
        <translation>не є типом</translation>
    </message>
    <message>
        <source>plugin cannot be loaded for module &quot;%1&quot;: %2</source>
        <translation>неможливо завантажити додаток для модуля &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
        <translation>не знайдено додаток &quot;%2&quot; модуля &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; version %2.%3 is defined more than once in module &quot;%4&quot;</source>
        <translation>&quot;%1&quot; версії %2.%3 визначено більше одного разу в модулі &quot;%4&quot;</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; version %2.%3 is not installed</source>
        <translation>модуль &quot;%1&quot; версії %2.%3 не встановлено</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>модуль &quot;%1&quot; не встановлено</translation>
    </message>
    <message>
        <source>&quot;%1&quot;: no such directory</source>
        <translation>&quot;%1&quot;: тека не існує</translation>
    </message>
    <message>
        <source>import &quot;%1&quot; has no qmldir and no namespace</source>
        <translation>import &quot;%1&quot; не має ні qmldir, ні namespace</translation>
    </message>
    <message>
        <source>File name case mismatch for &quot;%1&quot;</source>
        <translation>Регістр імені файлу не збігається для &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Module namespace &apos;%1&apos; does not match import URI &apos;%2&apos;</source>
        <translation>Простір імен модуля &apos;%1&apos; не збігається з URI імпорту &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Namespace &apos;%1&apos; has already been used for type registration</source>
        <translation>Простір імен &apos;%1&apos; вже було використано для реєстрації типу</translation>
    </message>
    <message>
        <source>Module &apos;%1&apos; does not contain a module identifier directive - it cannot be protected from external registrations.</source>
        <translation>Модуль &apos;%1&apos; не містить директиви ідентифікації модуля - він не може бути захищеним від зовнішніх реєстрацій.</translation>
    </message>
</context>
<context>
    <name>QQmlImportsPrivate</name>
    <message>
        <source>plugin cannot be loaded for module &quot;%1&quot;: %2</source>
        <translation type="obsolete">неможливо завантажити додаток для модуля &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; plugin &quot;%2&quot; not found</source>
        <translation type="obsolete">не знайдено додаток &quot;%2&quot; модуля &quot;%1&quot;</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; version %2.%3 is not installed</source>
        <translation type="obsolete">модуль &quot;%1&quot; версії %2.%3 не встановлено</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation type="obsolete">модуль &quot;%1&quot; не встановлено</translation>
    </message>
    <message>
        <source>&quot;%1&quot;: no such directory</source>
        <translation type="obsolete">&quot;%1&quot;: тека не існує</translation>
    </message>
    <message>
        <source>import &quot;%1&quot; has no qmldir and no namespace</source>
        <translation type="obsolete">import &quot;%1&quot; не має ні qmldir, ні namespace</translation>
    </message>
</context>
<context>
    <name>QQmlListModel</name>
    <message>
        <source>unable to enable dynamic roles as this model is not empty!</source>
        <translation>неможливо увімкнути динамічні ролі, оскільки ця модель не порожня!</translation>
    </message>
    <message>
        <source>unable to enable static roles as this model is not empty!</source>
        <translation>неможливо увімкнути статичні ролі, оскільки ця модель не порожня!</translation>
    </message>
    <message>
        <source>dynamic role setting must be made from the main thread, before any worker scripts are created</source>
        <translation>налаштування динамічної ролі має здійснюватись з головної нитки, до створення будь-яких скриптів-виконавців</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation>remove: індекси [%1 - %2] поза межами діапазону [0 - %3]</translation>
    </message>
    <message>
        <source>remove: incorrect number of arguments</source>
        <translation>remove: неправильна кількіст аргументів</translation>
    </message>
    <message>
        <source>insert: index %1 out of range</source>
        <translation>insert: індекс %1 поза межами діапазону</translation>
    </message>
    <message>
        <source>insert: value is not an object</source>
        <translation>insert: значення не є об’єктом</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation>move: поза межами діапазону</translation>
    </message>
    <message>
        <source>append: value is not an object</source>
        <translation>append: значення не є об’єктом</translation>
    </message>
    <message>
        <source>set: value is not an object</source>
        <translation>set: значення не є об’єктом</translation>
    </message>
    <message>
        <source>set: index %1 out of range</source>
        <translation>set: індекс %1 поза межами діапазону</translation>
    </message>
    <message>
        <source>ListElement: cannot contain nested elements</source>
        <translation>ListElement: не може містити вкладені елементи</translation>
    </message>
    <message>
        <source>ListElement: cannot use reserved &quot;id&quot; property</source>
        <translation>ListElement: не може використовувати зарезервовану властивість &quot;id&quot;</translation>
    </message>
    <message>
        <source>ListElement: improperly specified %1</source>
        <translation>ListModel: неправильно вказано &apos;%1&apos;</translation>
    </message>
    <message>
        <source>ListElement: improperly specified QT_TRANSLATE_NOOP</source>
        <translation>ListModel: неправильно вказано QT_TRANSLATE_NOOP</translation>
    </message>
    <message>
        <source>ListElement: cannot use script for property value</source>
        <translation>ListElement: неможливо використовувати скрипт в якості значення властивості</translation>
    </message>
    <message>
        <source>ListModel: undefined property &apos;%1&apos;</source>
        <translation>ListModel: невизначена властивість &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QQmlParser</name>
    <message>
        <source>Illegal syntax for exponential number</source>
        <translation>Неприпустимий синтаксис для експоненційного числа</translation>
    </message>
    <message>
        <source>Unclosed string at end of line</source>
        <translation>Незакритий рядок в кінці файлу</translation>
    </message>
    <message>
        <source>Illegal unicode escape sequence</source>
        <translation>Неприпустима керуюча послідовність Unicode</translation>
    </message>
    <message>
        <source>Stray newline in string literal</source>
        <translation>Зайвий символ нового рядка в рядковому літералі</translation>
    </message>
    <message>
        <source>Illegal hexadecimal escape sequence</source>
        <translation>Неприпустима шістнадцяткова керуюча послідовність</translation>
    </message>
    <message>
        <source>Octal escape sequences are not allowed</source>
        <translation>Вісімкові керуючі послідовност не дозволяються</translation>
    </message>
    <message>
        <source>Decimal numbers can&apos;t start with &apos;0&apos;</source>
        <translation>Десяткові числа не можуть починатись з &apos;0&apos;</translation>
    </message>
    <message>
        <source>At least one hexadecimal digit is required after &apos;0%1&apos;</source>
        <translation>Необхідна хоча б одна шістнадцяткова цифра після &apos;0%1&apos;</translation>
    </message>
    <message>
        <source>Invalid regular expression flag &apos;%0&apos;</source>
        <translation>Неправильний прапорець регулярного виразу ’%0’</translation>
    </message>
    <message>
        <source>Unterminated regular expression backslash sequence</source>
        <translation>Незавершена екранована послідовність регулярного виразу</translation>
    </message>
    <message>
        <source>Unterminated regular expression class</source>
        <translation>Незавершений клас регулярного виразу</translation>
    </message>
    <message>
        <source>Unterminated regular expression literal</source>
        <translation>Незавершений літерал регулярного виразу</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Синтаксична помилка</translation>
    </message>
    <message>
        <source>Unexpected token `%1&apos;</source>
        <translation>Неочікуваний токен `%1&apos;</translation>
    </message>
    <message>
        <source>Expected token `%1&apos;</source>
        <translation>Очікувався токен `%1&apos;</translation>
    </message>
    <message>
        <source>Property value set multiple times</source>
        <translation>Значення властивості встановлено декілька разів</translation>
    </message>
    <message>
        <source>Expected type name</source>
        <translation>Очікувалась назва типу</translation>
    </message>
    <message>
        <source>Invalid import qualifier ID</source>
        <translation>Неправильний ID специфікатору імпорту</translation>
    </message>
    <message>
        <source>Reserved name &quot;Qt&quot; cannot be used as an qualifier</source>
        <translation>Зарезервоване ім’я &quot;Qt&quot; не може бути застосоване в якості специфікатора</translation>
    </message>
    <message>
        <source>Script import qualifiers must be unique.</source>
        <translation>Специфікатори імпорту скрипту мають бути унікальними.</translation>
    </message>
    <message>
        <source>Script import requires a qualifier</source>
        <translation>Імпорт скрипту вимагає специфікатора</translation>
    </message>
    <message>
        <source>Library import requires a version</source>
        <translation>Імпорт бібліотеки вимагає версії</translation>
    </message>
    <message>
        <source>Expected parameter type</source>
        <translation>Очікувався тип параметра</translation>
    </message>
    <message>
        <source>Invalid signal parameter type: </source>
        <translation>Неправильний тип параметра сигналу:</translation>
    </message>
    <message>
        <source>Invalid property type modifier</source>
        <translation>Неправильний модифікатор типу властивості</translation>
    </message>
    <message>
        <source>Unexpected property type modifier</source>
        <translation>Неочікуваний модифікатор типу властивості</translation>
    </message>
    <message>
        <source>Expected property type</source>
        <translation>Очікувався тип властивості</translation>
    </message>
    <message>
        <source>JavaScript declaration outside Script element</source>
        <translation>Декларація JavaScript поза межами елемента Script</translation>
    </message>
    <message>
        <source>Imported file must be a script</source>
        <translation>Імпортований файл має бути скриптом</translation>
    </message>
    <message>
        <source>File import requires a qualifier</source>
        <translation>Імпорт файлу вимагає специфікатора</translation>
    </message>
    <message>
        <source>Invalid import qualifier</source>
        <translation>Неправильний специфікатор імпорту</translation>
    </message>
    <message>
        <source>Invalid module URI</source>
        <translation>Неправильний URI модуля</translation>
    </message>
    <message>
        <source>Module import requires a version</source>
        <translation>Імпорт модуля вимагає версії</translation>
    </message>
    <message>
        <source>Module import requires a qualifier</source>
        <translation>Імпорт модуля вимагає специфікатора</translation>
    </message>
</context>
<context>
    <name>QQmlPartsModel</name>
    <message>
        <source>The group of a DelegateModel cannot be changed within onChanged</source>
        <translation>Неможливо змінити групу DelegateModel всередині onChanged</translation>
    </message>
    <message>
        <source>Delegate component must be Package type.</source>
        <translation>Компонент делегату має бути типу Package.</translation>
    </message>
</context>
<context>
    <name>QQmlRewrite</name>
    <message>
        <source>Signal uses unnamed parameter followed by named parameter.</source>
        <translation>Сигнал використовує неіменований параметр перед іменованим.</translation>
    </message>
    <message>
        <source>Signal parameter &quot;%1&quot; hides global variable.</source>
        <translation>Параметр сигналу &quot;%1&quot; ховає глобальну змінну.</translation>
    </message>
</context>
<context>
    <name>QQmlScriptBlob</name>
    <message>
        <source>Script %1 unavailable</source>
        <translation type="obsolete">Скрипт %1 недоступний</translation>
    </message>
</context>
<context>
    <name>QQmlTypeLoader</name>
    <message>
        <source>Cannot update qmldir content for &apos;%1&apos;</source>
        <translation>Неможливо оновити зміст qmldir для &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Script %1 unavailable</source>
        <translation>Скрипт %1 недоступний</translation>
    </message>
    <message>
        <source>Type %1 unavailable</source>
        <translation>Тип %1 недоступний</translation>
    </message>
    <message>
        <source>module &quot;%1&quot; is not installed</source>
        <translation>модуль &quot;%1&quot; не встановлено</translation>
    </message>
    <message>
        <source>Namespace %1 cannot be used as a type</source>
        <translation>Простір імен %1 не може бути використаний як тип</translation>
    </message>
    <message>
        <source>Unreported error adding script import to import database</source>
        <translation>Неповідомлена помилка додавання імпорту скрипту до бази даних імпорту</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>QQmlVME</name>
    <message>
        <source>Unable to create object of type %1</source>
        <translation>Неможливо створити об’єкт типу %1</translation>
    </message>
    <message>
        <source>Cannot assign value %1 to property %2</source>
        <translation>Неможливо призначити властивості %2 значення %1</translation>
    </message>
    <message>
        <source>Cannot assign object type %1 with no default method</source>
        <translation>Неможливо призначити об’єкт типу %1 без методу за замовчуванням</translation>
    </message>
    <message>
        <source>Cannot connect mismatched signal/slot %1 %vs. %2</source>
        <translation>Неможливо з’єднати несумісний сигнал/слот (%1 проти %2)</translation>
    </message>
    <message>
        <source>Cannot assign an object to signal property %1</source>
        <translation>Неможливо призначити об’єкт до властивості сигналу %1</translation>
    </message>
    <message>
        <source>Cannot assign object to read only list</source>
        <translation>Неможливо призначити об&apos;єкт списку лише для читання</translation>
    </message>
    <message>
        <source>Cannot assign object to list</source>
        <translation>Неможливо призначити об&apos;єкт списку</translation>
    </message>
    <message>
        <source>Cannot assign object to interface property</source>
        <translation>Неможливо призначити об’єкт до властивості інтерфейсу</translation>
    </message>
    <message>
        <source>Unable to create attached object</source>
        <translation>Неможливо створити прикріплений об’єкт</translation>
    </message>
    <message>
        <source>Cannot set properties on %1 as it is null</source>
        <translation>Неможливо встановити властивості для %1, оскільки він нульовий</translation>
    </message>
</context>
<context>
    <name>QQuickAbstractAnimation</name>
    <message>
        <source>Cannot animate non-existent property &quot;%1&quot;</source>
        <translation>Неможливо анімувати неіснуючу властивість &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot animate read-only property &quot;%1&quot;</source>
        <translation>Неможливо анімувати властивість лише для читання &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Animation is an abstract class</source>
        <translation>Animation - це абстрактний клас</translation>
    </message>
</context>
<context>
    <name>QQuickAccessibleAttached</name>
    <message>
        <source>Accessible is only available via attached properties</source>
        <translation>Accessible доступна лише через прикріплені властивості</translation>
    </message>
</context>
<context>
    <name>QQuickAnchorAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Не можу встановити тривалість &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickAnchors</name>
    <message>
        <source>Possible anchor loop detected on fill.</source>
        <translation>Виявлено імовірну циклічну прив&apos;язку до fill.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on centerIn.</source>
        <translation>Виявлено імовірну циклічну прив&apos;язку до centerIn.</translation>
    </message>
    <message>
        <source>Cannot anchor to an item that isn&apos;t a parent or sibling.</source>
        <translation>Неможливо прив&apos;язати до елемента, що не є батьківським чи сусіднім.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on vertical anchor.</source>
        <translation>Виявлено імовірну циклічну прив&apos;язку до вертикальної прив&apos;язки.</translation>
    </message>
    <message>
        <source>Possible anchor loop detected on horizontal anchor.</source>
        <translation>Виявлено імовірну циклічну прив&apos;язку до горизонтальної прив&apos;язки.</translation>
    </message>
    <message>
        <source>Cannot specify left, right, and horizontalCenter anchors at the same time.</source>
        <translation>Неможливо задати прив&apos;язки зліва, справа та центру по горизонталі одночасно.</translation>
    </message>
    <message>
        <source>Cannot anchor to a null item.</source>
        <translation>Неможливо прив&apos;язати до нульового елемента.</translation>
    </message>
    <message>
        <source>Cannot anchor a horizontal edge to a vertical edge.</source>
        <translation>Неможливо прив&apos;язати горизонтальний край до вертикального.</translation>
    </message>
    <message>
        <source>Cannot anchor item to self.</source>
        <translation>Неможливо прив&apos;язати елемент до самого себе.</translation>
    </message>
    <message>
        <source>Cannot specify top, bottom, and verticalCenter anchors at the same time.</source>
        <translation>Неможливо задати прив&apos;язки догори, донизу та центру по вертикалі одночасно.</translation>
    </message>
    <message>
        <source>Baseline anchor cannot be used in conjunction with top, bottom, or verticalCenter anchors.</source>
        <translation>Неможливо використати базову прив&apos;язку разом з верхньої, нижньою чи центральною по вертикалі.</translation>
    </message>
    <message>
        <source>Cannot anchor a vertical edge to a horizontal edge.</source>
        <translation>Неможливо прив&apos;язати вертикальний край до горизонтального.</translation>
    </message>
</context>
<context>
    <name>QQuickAnimatedImage</name>
    <message>
        <source>Qt was built without support for QMovie</source>
        <translation>Бібліотека Qt була зібрана без підтримки QMovie</translation>
    </message>
</context>
<context>
    <name>QQuickApplication</name>
    <message>
        <source>Application is an abstract class</source>
        <translation>Application - це абстрактний клас</translation>
    </message>
</context>
<context>
    <name>QQuickBehavior</name>
    <message>
        <source>Cannot change the animation assigned to a Behavior.</source>
        <translation>Неможливо змінити анімацію, призначену до поведінки.</translation>
    </message>
</context>
<context>
    <name>QQuickDragAttached</name>
    <message>
        <source>Drag is only available via attached properties</source>
        <translation>Drag доступна лише через прикріплені властивості</translation>
    </message>
</context>
<context>
    <name>QQuickFlipable</name>
    <message>
        <source>front is a write-once property</source>
        <translation>Властивість front лише для одноразового запису</translation>
    </message>
    <message>
        <source>back is a write-once property</source>
        <translation>Властивість back лише для одноразового запису</translation>
    </message>
</context>
<context>
    <name>QQuickItemView</name>
    <message>
        <source>ItemView is an abstract base class</source>
        <translation>ItemView - це абстрактний клас</translation>
    </message>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Делегат має бути типу Item</translation>
    </message>
</context>
<context>
    <name>QQuickKeyNavigationAttached</name>
    <message>
        <source>KeyNavigation is only available via attached properties</source>
        <translation>KeyNavigation доступна лише через прикріплені властивості</translation>
    </message>
</context>
<context>
    <name>QQuickKeysAttached</name>
    <message>
        <source>Keys is only available via attached properties</source>
        <translation>Keys доступні лише через прикріплені властивості</translation>
    </message>
</context>
<context>
    <name>QQuickLayoutMirroringAttached</name>
    <message>
        <source>LayoutDirection attached property only works with Items</source>
        <translation>Прикріплена властивість LayoutDirection працює лише з Items</translation>
    </message>
    <message>
        <source>LayoutMirroring is only available via attached properties</source>
        <translation>LayoutMirroring доступна лише через прикріплені властивості</translation>
    </message>
</context>
<context>
    <name>QQuickListModel</name>
    <message>
        <source>unable to enable dynamic roles as this model is not empty!</source>
        <translation type="obsolete">неможливо увімкнути динамічні ролі, оскільки ця модель не порожня!</translation>
    </message>
    <message>
        <source>unable to enable static roles as this model is not empty!</source>
        <translation type="obsolete">неможливо увімкнути статичні ролі, оскільки ця модель не порожня!</translation>
    </message>
    <message>
        <source>dynamic role setting must be made from the main thread, before any worker scripts are created</source>
        <translation type="obsolete">налаштування динамічної ролі має здійснюватись з головної нитки, до створення будь-яких скриптів-виконавців</translation>
    </message>
    <message>
        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
        <translation type="obsolete">remove: індекси [%1 - %2] поза межами діапазону [0 - %3]</translation>
    </message>
    <message>
        <source>remove: incorrect number of arguments</source>
        <translation type="obsolete">remove: неправильна кількіст аргументів</translation>
    </message>
    <message>
        <source>insert: index %1 out of range</source>
        <translation type="obsolete">insert: індекс %1 поза межами діапазону</translation>
    </message>
    <message>
        <source>insert: value is not an object</source>
        <translation type="obsolete">insert: значення не є об’єктом</translation>
    </message>
    <message>
        <source>move: out of range</source>
        <translation type="obsolete">move: поза межами діапазону</translation>
    </message>
    <message>
        <source>append: value is not an object</source>
        <translation type="obsolete">append: значення не є об’єктом</translation>
    </message>
    <message>
        <source>set: value is not an object</source>
        <translation type="obsolete">set: значення не є об’єктом</translation>
    </message>
    <message>
        <source>set: index %1 out of range</source>
        <translation type="obsolete">set: індекс %1 поза межами діапазону</translation>
    </message>
    <message>
        <source>ListElement: cannot contain nested elements</source>
        <translation type="obsolete">ListElement: не може містити вкладені елементи</translation>
    </message>
    <message>
        <source>ListElement: cannot use reserved &quot;id&quot; property</source>
        <translation type="obsolete">ListElement: не може використовувати зарезервовану властивість &quot;id&quot;</translation>
    </message>
    <message>
        <source>ListElement: improperly specified %1</source>
        <translation type="obsolete">ListModel: неправильно вказано &apos;%1&apos;</translation>
    </message>
    <message>
        <source>ListElement: improperly specified QT_TRANSLATE_NOOP</source>
        <translation type="obsolete">ListModel: неправильно вказано QT_TRANSLATE_NOOP</translation>
    </message>
    <message>
        <source>ListElement: cannot use script for property value</source>
        <translation type="obsolete">ListElement: неможливо використовувати скрипт в якості значення властивості</translation>
    </message>
    <message>
        <source>ListModel: undefined property &apos;%1&apos;</source>
        <translation type="obsolete">ListModel: невизначена властивість &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QQuickLoader</name>
    <message>
        <source>setSource: value is not an object</source>
        <translation>setSource: значення не є об’єктом</translation>
    </message>
</context>
<context>
    <name>QQuickLoaderPrivate</name>
    <message>
        <source>setSource: value is not an object</source>
        <translation type="obsolete">setSource: значення не є об’єктом</translation>
    </message>
</context>
<context>
    <name>QQuickPaintedItem</name>
    <message>
        <source>Cannot create instance of abstract class PaintedItem</source>
        <translation>Неможливо створити екземпляр абстрактного класу PaintedItem</translation>
    </message>
</context>
<context>
    <name>QQuickParentAnimation</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Неможливо зберегти зовнішній вигляд при складному перетворенні</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Неможливо зберегти зовнішній вигляд при неоднорідному масштабі</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Неможливо зберегти зовнішній вигляд при нульовому масштабі</translation>
    </message>
</context>
<context>
    <name>QQuickParentChange</name>
    <message>
        <source>Unable to preserve appearance under complex transform</source>
        <translation>Неможливо зберегти зовнішній вигляд при складному перетворенні</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under non-uniform scale</source>
        <translation>Неможливо зберегти зовнішній вигляд при неоднорідному масштабі</translation>
    </message>
    <message>
        <source>Unable to preserve appearance under scale of 0</source>
        <translation>Неможливо зберегти зовнішній вигляд при нульовому масштабі</translation>
    </message>
</context>
<context>
    <name>QQuickPathAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Не можу встановити тривалість &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickPathView</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Делегат має бути типу Item</translation>
    </message>
</context>
<context>
    <name>QQuickPauseAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Не можу встановити тривалість &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickPixmap</name>
    <message>
        <source>Error decoding: %1: %2</source>
        <translation>Помилка декодування: %1: %2</translation>
    </message>
    <message>
        <source>Invalid image provider: %1</source>
        <translation>Неправильний постачальник зображень: %1</translation>
    </message>
    <message>
        <source>Failed to get image from provider: %1</source>
        <translation>Збій отримання зображення від постачальника: %1</translation>
    </message>
    <message>
        <source>Failed to get texture from provider: %1</source>
        <translation>Збій отримання текстури від постачальника: %1</translation>
    </message>
    <message>
        <source>Cannot open: %1</source>
        <translation>Неможливо відкрити: %1</translation>
    </message>
    <message>
        <source>Invalid image data: %1</source>
        <translation>Неправильні дані зображення: %1</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyAnimation</name>
    <message>
        <source>Cannot set a duration of &lt; 0</source>
        <translation>Не можу встановити тривалість &lt; 0</translation>
    </message>
</context>
<context>
    <name>QQuickPropertyChanges</name>
    <message>
        <source>PropertyChanges does not support creating state-specific objects.</source>
        <translation>PropertyChanges не підтримує створення об’єктів специфічних до стану.</translation>
    </message>
    <message>
        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
        <translation>Неможливо призначити неіснуючій властивості &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Cannot assign to read-only property &quot;%1&quot;</source>
        <translation>Неможливо призначити властивості лише для читання &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickRepeater</name>
    <message>
        <source>Delegate must be of Item type</source>
        <translation>Делегат має бути типу Item</translation>
    </message>
</context>
<context>
    <name>QQuickShaderEffectMesh</name>
    <message>
        <source>Cannot create instance of abstract class ShaderEffectMesh.</source>
        <translation>Неможливо створити екземпляр абстрактного класу ShaderEffectMesh.</translation>
    </message>
</context>
<context>
    <name>QQuickTextUtil</name>
    <message>
        <source>%1 does not support loading non-visual cursor delegates.</source>
        <translation>%1 не підтримує завантаження невізуальних делегатів курсору.</translation>
    </message>
    <message>
        <source>Could not load cursor delegate</source>
        <translation>Не вдалося завантажити делегат курсору</translation>
    </message>
</context>
<context>
    <name>QQuickViewTransitionAttached</name>
    <message>
        <source>ViewTransition is only available via attached properties</source>
        <translation>ViewTransition доступна лише через прикріплені властивості</translation>
    </message>
</context>
<context>
    <name>QQuickVisualDataGroup</name>
    <message>
        <source>Group names must start with a lower case letter</source>
        <translation type="obsolete">Назви груп повинні почиантись з малої літери</translation>
    </message>
    <message>
        <source>get: index out of range</source>
        <translation type="obsolete">get: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>insert: index out of range</source>
        <translation type="obsolete">insert: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>create: index out of range</source>
        <translation type="obsolete">create: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>resolve: from index out of range</source>
        <translation type="obsolete">resolve: індекс from поза межами діапазону</translation>
    </message>
    <message>
        <source>resolve: from index invalid</source>
        <translation type="obsolete">resolve: неправильний індекс from</translation>
    </message>
    <message>
        <source>resolve: to index out of range</source>
        <translation type="obsolete">resolve: індекс to поза межами діапазону</translation>
    </message>
    <message>
        <source>resolve: to index invalid</source>
        <translation type="obsolete">resolve: неправильний індекс to</translation>
    </message>
    <message>
        <source>resolve: from is not an unresolved item</source>
        <translation type="obsolete">resolve: from не є нерозв&apos;язаним елементом</translation>
    </message>
    <message>
        <source>resolve: to is not a model item</source>
        <translation type="obsolete">resolve: to не є елементом моделі</translation>
    </message>
    <message>
        <source>remove: invalid index</source>
        <translation type="obsolete">remove: неправильний індекс</translation>
    </message>
    <message>
        <source>remove: index out of range</source>
        <translation type="obsolete">remove: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>remove: invalid count</source>
        <translation type="obsolete">remove: неправильна кількість</translation>
    </message>
    <message>
        <source>addGroups: index out of range</source>
        <translation type="obsolete">addGroups: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>addGroups: invalid count</source>
        <translation type="obsolete">addGroups: неправильна кількість</translation>
    </message>
    <message>
        <source>removeGroups: index out of range</source>
        <translation type="obsolete">removeGroups: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>removeGroups: invalid count</source>
        <translation type="obsolete">removeGroups: неправильна кількість</translation>
    </message>
    <message>
        <source>setGroups: index out of range</source>
        <translation type="obsolete">setGroups: індекс поза межами діапазону</translation>
    </message>
    <message>
        <source>setGroups: invalid count</source>
        <translation type="obsolete">setGroups: неправильна кількість</translation>
    </message>
    <message>
        <source>move: invalid from index</source>
        <translation type="obsolete">move: неправильний індекс from</translation>
    </message>
    <message>
        <source>move: invalid to index</source>
        <translation type="obsolete">move: неправильний індекс</translation>
    </message>
    <message>
        <source>move: invalid count</source>
        <translation type="obsolete">move: неправильна кількість</translation>
    </message>
    <message>
        <source>move: from index out of range</source>
        <translation type="obsolete">move: індекс from поза межами діапазону</translation>
    </message>
    <message>
        <source>move: to index out of range</source>
        <translation type="obsolete">move: індекс to поза межами діапазону</translation>
    </message>
</context>
<context>
    <name>QQuickVisualDataModel</name>
    <message>
        <source>The delegate of a VisualDataModel cannot be changed within onUpdated.</source>
        <translation type="obsolete">Неможливо змінити делегат VisualDataModel всередині onUpdated.</translation>
    </message>
    <message>
        <source>The maximum number of supported VisualDataGroups is 8</source>
        <translation type="obsolete">Підтримується максимум 8 VisualDataGroup</translation>
    </message>
    <message>
        <source>The group of a VisualDataModel cannot be changed within onChanged</source>
        <translation type="obsolete">Неможливо змінити групу VisualDataModel всередині onChanged</translation>
    </message>
    <message>
        <source>Delegate component must be Item type.</source>
        <translation type="obsolete">Компонент делегату має бути типу Item.</translation>
    </message>
</context>
<context>
    <name>QQuickVisualPartsModel</name>
    <message>
        <source>The group of a VisualDataModel cannot be changed within onChanged</source>
        <translation type="obsolete">Неможливо змінити групу VisualDataModel всередині onChanged</translation>
    </message>
    <message>
        <source>Delegate component must be Package type.</source>
        <translation type="obsolete">Компонент делегату має бути типу Package.</translation>
    </message>
</context>
<context>
    <name>QQuickXmlListModel</name>
    <message>
        <source>&quot;%1&quot; duplicates a previous role name and will be disabled.</source>
        <translation>&quot;%1&quot; повторює назву попередньої ролі та буде вимкнене.</translation>
    </message>
    <message>
        <source>invalid query: &quot;%1&quot;</source>
        <translation>неправильний запит &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlListModelRole</name>
    <message>
        <source>An XmlRole query must not start with &apos;/&apos;</source>
        <translation>Запит XmlRole не повинен починатись з &apos;/&apos;</translation>
    </message>
</context>
<context>
    <name>QQuickXmlRoleList</name>
    <message>
        <source>An XmlListModel query must start with &apos;/&apos; or &quot;//&quot;</source>
        <translation>Запит XmlListModel не повинен починатись з &apos;/&apos; або &quot;//&quot;</translation>
    </message>
</context>
<context>
    <name>QV4Bindings</name>
    <message>
        <source>Binding loop detected for property &quot;%1&quot;</source>
        <translation>Знайдено циклічну прив’язку для властивості &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>qmlRegisterType</name>
    <message>
        <source>Invalid QML %1 name &quot;%2&quot;</source>
        <translation>Неправильне ім&apos;я &quot;%2&quot; для QML %1 </translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into unregistered namespace &apos;%3&apos;</source>
        <translation>Неможливо встановити %1 &apos;%2&apos; до незареєстрованого простору імен &apos;%3&apos;</translation>
    </message>
    <message>
        <source>Cannot install %1 &apos;%2&apos; into protected namespace &apos;%3&apos;</source>
        <translation>Неможливо встановити %1 &apos;%2&apos; до захищеного простору імен &apos;%3&apos;</translation>
    </message>
</context>
</TS>
